Address class

Constructors

Address({required String country, String? line1, String? line2, String? area1, required String area2, String? postalCode})
const

Properties

area1 → String?
final
area2 → String
final
country → String
final
hashCode → int
The hash code for this object.
no setterinherited
line1 → String?
final
line2 → String?
final
postalCode → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited