PaymentMethodWidgetState class

Inheritance

Constructors

PaymentMethodWidgetState()

Properties

activeWebViewKey ↔ GlobalKey<TosspaymentsInAppWebviewState>?
SDK 내부 전용 — 외부(가맹점)에서 접근/수정하지 말 것.
getter/setter pair
amount ↔ Amount?
getter/setter pair
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
domain → String?
no setterinherited
eventManager → EventManager
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
orderId ↔ String
getter/setter pairinherited
redirectUrl → String?
no setterinherited
requestPaymentInProgress ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widget → WidgetContainer
The current configuration.
no setterinherited
widgetJavascriptChannels → Set<JavascriptChannel>
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
addJavascriptChannels(Set<JavascriptChannel> channels) → void
웹뷰에 JavascriptChannel set channels를 추가
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant WidgetContainer oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
evaluateJavascript(String script) → void
script 를 웹뷰에서 evaluate (evaluate 결과 응답이 필요 없을 경우 사용)
inherited
evaluateJavascriptFuture(String script, String bridge) → Future
script를 evaluate한 후, bridge 이름의 JavascriptChannel로 받은 params를 Future로 반환
inherited
evaluateJavascriptWithResolve(String script) → Future
고유한 세션 키로 script를 evaluate한 후, JavascriptChannel로 받은 해당 세션 키의 params를 Future로 반환
inherited
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
renderPaymentMethods({required Amount amount, RenderPaymentMethodsOptions? options}) → Future<PaymentMethodWidgetControl>
renderWidget({required String renderScript}) → Future
inherited
requestPayment({required PaymentInfo paymentInfo}) → Future
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
updateHeight(double height) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited